@@ -19,6 +19,7 @@
     clippy::dbg_macro,
     clippy::print_stdout,
     clippy::unimplemented,
+    clippy::use_self,
     missing_copy_implementations,
     missing_docs,
     non_snake_case,
@@ -28,17 +29,8 @@
 )]
 #![allow(clippy::single_component_path_imports)]
 
-//! TLS protocol related components for DNS over TLS
+//! Deprecated and removed as of 0.21.0, see the dns-over-rustls feature in `trust-dns-proto`
 
-#[macro_use]
-extern crate log;
+#![deprecated = "moved to trust_dns_proto::rustls"]
 
-pub mod tls_client_stream;
-pub mod tls_server;
-pub mod tls_stream;
-
-pub use self::tls_client_stream::{tls_client_connect, TlsClientStream};
-pub use self::tls_stream::{tls_connect, tls_from_stream, TlsStream};
-
-#[cfg(test)]
-mod tests;
+pub use trust_dns_proto::rustls::*;
